Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorslewis2008-10-05 20:02:42 +0000
committerslewis2008-10-05 20:02:42 +0000
commit5c278fa69d32359f4d0e5fa93bb24db9017ddf88 (patch)
treea5a8bd30b9ac781bc45f47b4b84ee289ac14d614 /framework/bundles/org.eclipse.ecf.sync
parent93dc1354e9dc0de080e256f3ed253d2eb857985f (diff)
downloadorg.eclipse.ecf-5c278fa69d32359f4d0e5fa93bb24db9017ddf88.tar.gz
org.eclipse.ecf-5c278fa69d32359f4d0e5fa93bb24db9017ddf88.tar.xz
org.eclipse.ecf-5c278fa69d32359f4d0e5fa93bb24db9017ddf88.zip
Renamed deserialize method
Diffstat (limited to 'framework/bundles/org.eclipse.ecf.sync')
-rw-r--r--framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/internal/sync/doc/cola/ColaSynchronizationStrategy.java2
-rw-r--r--framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/internal/sync/doc/identity/IdentitySynchronizationStrategy.java2
-rw-r--r--framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/sync/doc/IDocumentSynchronizationStrategy.java4
3 files changed, 4 insertions, 4 deletions
diff --git a/framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/internal/sync/doc/cola/ColaSynchronizationStrategy.java b/framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/internal/sync/doc/cola/ColaSynchronizationStrategy.java
index 96d3a44df..e9d4362be 100644
--- a/framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/internal/sync/doc/cola/ColaSynchronizationStrategy.java
+++ b/framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/internal/sync/doc/cola/ColaSynchronizationStrategy.java
@@ -203,7 +203,7 @@ public class ColaSynchronizationStrategy implements IDocumentSynchronizationStra
/* (non-Javadoc)
* @see org.eclipse.ecf.sync.doc.IDocumentSynchronizationStrategy#toDocumentChangeMessage(byte[])
*/
- public IDocumentChange deserializeToDocumentChange(byte[] bytes) throws SerializationException {
+ public IDocumentChange deserializeRemoteChange(byte[] bytes) throws SerializationException {
return DocumentChangeMessage.deserialize(bytes);
}
diff --git a/framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/internal/sync/doc/identity/IdentitySynchronizationStrategy.java b/framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/internal/sync/doc/identity/IdentitySynchronizationStrategy.java
index 796e0cd78..d6bdaf924 100644
--- a/framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/internal/sync/doc/identity/IdentitySynchronizationStrategy.java
+++ b/framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/internal/sync/doc/identity/IdentitySynchronizationStrategy.java
@@ -25,7 +25,7 @@ public class IdentitySynchronizationStrategy implements IDocumentSynchronization
/* (non-Javadoc)
* @see org.eclipse.ecf.sync.doc.IDocumentSynchronizationStrategy#deserializeToDocumentChange(byte[])
*/
- public IDocumentChange deserializeToDocumentChange(byte[] bytes) throws SerializationException {
+ public IDocumentChange deserializeRemoteChange(byte[] bytes) throws SerializationException {
return DocumentChangeMessage.deserialize(bytes);
}
diff --git a/framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/sync/doc/IDocumentSynchronizationStrategy.java b/framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/sync/doc/IDocumentSynchronizationStrategy.java
index 776e66861..972e56942 100644
--- a/framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/sync/doc/IDocumentSynchronizationStrategy.java
+++ b/framework/bundles/org.eclipse.ecf.sync/src/org/eclipse/ecf/sync/doc/IDocumentSynchronizationStrategy.java
@@ -20,7 +20,7 @@ package org.eclipse.ecf.sync.doc;
* should call {@link #registerLocalChange(IDocumentChange)} when local
* changes occur, and then serialize returned {@link IDocumentChangeMessage}s and
* deliver the change message to remotes. When remote change messages are received,
* they should first be deserized via {@link #deserializeToDocumentChange(byte[])}, and then
* passed to {@link #transformRemoteChange(IDocumentChange)} to transform
* the change so that when the returned IDocumentChanges are applied to the local
* document its state will be consistent with other client(s).
@@ -54,5 +54,5 @@ public interface IDocumentSynchronizationStrategy {
* @return IDocumentChange instance from bytes. Will not be <code>null</code>.
* @throws SerializationException thrown if some problem deserializing given bytes.
*/
- public IDocumentChange deserializeToDocumentChange(byte[] bytes) throws SerializationException;
+ public IDocumentChange deserializeRemoteChange(byte[] bytes) throws SerializationException;
}

Back to the top
@@ -20,7 +20,7 @@ package org.eclipse.ecf.sync.doc;
* changes occur, and then serialize returned {@link IDocumentChangeMessage}s and
* deliver the change message to remotes. When remote change messages are received,
- * they should first be deserized via {@link #deserializeToDocumentChange(byte[])}, and then
+ * they should first be deserized via {@link #deserializeRemoteChange(byte[])}, and then
* passed to {@link #transformRemoteChange(IDocumentChange)} to transform
* the change so that when the returned IDocumentChanges are applied to the local